import 'package:eyflutter_uikit/eyflutter_uikit.dart';
import 'package:eyflutter_uikit_example/fragment_page.dart';
import 'package:flutter/material.dart';

mixin FragmentPageController {
  void onContentClick();
}

class ConvexBottomBarPage extends StatefulWidget {
  const ConvexBottomBarPage({Key? key}) : super(key: key);

  @override
  _ConvexBottomBarPageState createState() => _ConvexBottomBarPageState();
}

class _ConvexBottomBarPageState extends State<ConvexBottomBarPage> with BottomBarListener, FragmentPageController {
  BottomBarController? bottomBarController;

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: BottomBarWidget(
        barStyle: BottomBarStyle.middleConvex,
        color: const Color(0xff666666),
        fixedColor: const Color(0xff3D9219),
        currentItem: 0,
        tabWidgets: [
          FragmentPage(index: 1, controller: this),
          FragmentPage(index: 2, controller: this),
          FragmentPage(index: 3, controller: this),
          FragmentPage(index: 4, controller: this)
        ],
        items: _buildBottomBars(),
        convexIconMargin: 5,
        top: -15,
        convexSize: 80,
        elevation: 8,
        listener: this,
        backgroundColor: const Color(0xffF1EDE1),
      ),
      top: false,
    );
  }

  List<BottomBarItem> _buildBottomBars() {
    return [
      BottomBarItem(
        icon: buildTabBarItem(
          Icons.build,
          "首页",
          const Color(0xff3B372C),
          13,
        ),
        activeIcon: buildTabBarItem(
          Icons.build,
          "首页",
          const Color(0x803B372C),
          13,
        ),
      ),
      BottomBarItem(
        icon: buildTabBarItem(
          Icons.build,
          "分类",
          const Color(0xff3B372C),
          13,
        ),
        activeIcon: buildTabBarItem(
          Icons.build,
          "分类",
          const Color(0x803B372C),
          13,
        ),
      ),
      BottomBarItem(
        isConvex: true,
        convex: Container(
          width: 50,
          height: 50,
          color: Colors.transparent,
          padding: const EdgeInsets.only(bottom: 20),
        ),
      ),
      BottomBarItem(
        icon: buildTabBarItem(
          Icons.build,
          "发现",
          const Color(0xff3B372C),
          13,
        ),
        activeIcon: buildTabBarItem(
          Icons.build,
          "发现",
          const Color(0x803B372C),
          13,
        ),
      ),
      BottomBarItem(
        icon: buildTabBarItem(
          Icons.build,
          "我的",
          const Color(0xff3B372C),
          13,
        ),
        activeIcon: buildTabBarItem(
          Icons.build,
          "我的",
          const Color(0x803B372C),
          13,
        ),
      ),
    ];
  }

  Widget buildTabBarItem(IconData image, String text, Color color, double fontSize) {
    return Column(
      mainAxisSize: MainAxisSize.max,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        Icon(image, color: color),
        Text(
          text,
          style: TextStyle(color: color, fontSize: fontSize),
        ),
      ],
    );
  }

  @override
  void onContentClick() {
    bottomBarController?.onBottomBarItemSelected(0);
  }

  @override
  void onBottomBarBuilder(BottomBarController controller) {
    bottomBarController = controller;
  }

  @override
  Future<bool> onBottomBarItemClick(int currentIndex, String tag, extra) {
    return Future.value(true);
  }
}
