import 'package:eyflutter_uikit/eyflutter_uikit.dart';
import 'package:flutter/material.dart';

class PopWindowWidget extends StatefulWidget {
  /// 内边距
  final EdgeInsetsGeometry? padding;

  /// 外边距
  final EdgeInsetsGeometry? margin;

  /// 子组件
  final Widget child;

  final Function(PopWidgetController controller) buildCall;

  const PopWindowWidget({Key? key, this.padding, this.margin, required this.child, required this.buildCall})
      : super(key: key);

  @override
  _PopWindowWidgetState createState() => _PopWindowWidgetState();
}

class _PopWindowWidgetState extends State<PopWindowWidget> {
  PopWidgetController popWidgetController = PopWidgetController();

  @override
  void initState() {
    super.initState();
    widget.buildCall(popWidgetController);
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: 60,
      height: 30,
      child: PopWidget(
        controller: popWidgetController,
        arrowColor: const Color(0xffFCF9F0),
        child: widget.child,
        horizontalMargin: 0,
        verticalMargin: -20,
        arrowUp: Container(
          padding: const EdgeInsets.only(top: 40),
          child: IconWidget(
            Icons.arrow_upward,
            size: 36,
          ),
        ),
        onPopShowCall: () {},
        onPopHideCall: () {},
        menuBuilder: () => const _PopWindowContent(),
        pressType: PressType.singleClick,
        arrowOffset: const Offset(0, 10),
      ),
    );
  }
}

class _PopWindowContent extends StatefulWidget {
  const _PopWindowContent({Key? key}) : super(key: key);

  @override
  _PopWindowContentState createState() => _PopWindowContentState();
}

class _PopWindowContentState extends State<_PopWindowContent> {
  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaUtils.instance.screenWidth - 40,
      height: 90,
      padding: const EdgeInsets.all(16),
      margin: const EdgeInsets.only(left: 20, right: 20),
      decoration: const BoxDecoration(
        color: Color(0xffFCF9F0),
        borderRadius: BorderRadius.all(Radius.circular(8)),
      ),
      child: Row(
        mainAxisSize: MainAxisSize.max,
        children: const [
          Expanded(
              child: Text(
            "如果您已经学会这首诗，点击可以标记为已学，我们会随机在温故列表显示已学的诗词。",
            style: TextStyle(color: Color(0xe63B372C), fontSize: 12),
            maxLines: 4,
            overflow: TextOverflow.ellipsis,
            softWrap: true,
          )),
          Text("知道了"),
        ],
      ),
    );
  }
}
