import 'package:flutter/material.dart';

class PrimaryButton extends StatelessWidget {
  /// 按钮文本
  final String text;

  /// 文本大小
  final double fontSize;

  /// 文本颜色
  final Color textColor;

  /// 事件回调
  final VoidCallback onPressed;

  /// 组件宽度
  final double? width;

  /// 组件高度
  final double? height;

  /// 背景颜色
  final Color backgroundColor;

  /// 按钮按下时颜色
  final Color? overlayColor;

  /// 组件圆角
  final BorderRadiusGeometry borderRadius;

  /// 子组件,设置该值后文本相关属性失效
  final Widget? child;

  /// 边框颜色
  final Color borderColor;

  /// 按钮内边距
  final EdgeInsetsGeometry padding;

  /// 按钮外边距
  final EdgeInsetsGeometry margin;

  /// 是否显示组件
  final bool visible;

  /// 按钮是否启用
  final bool enable;

  const PrimaryButton({
    Key? key,
    this.text = "",
    required this.onPressed,
    this.fontSize = 14,
    this.textColor = const Color(0xff222222),
    this.width,
    this.height = 38,
    this.backgroundColor = const Color(0xffEEEBD7),
    this.overlayColor,
    this.borderRadius = const BorderRadius.all(Radius.circular(30)),
    this.child,
    this.borderColor = const Color(0xffEEEBD7),
    this.margin = EdgeInsets.zero,
    this.visible = true,
    this.padding = EdgeInsets.zero,
    this.enable = true,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Visibility(
      child: Container(
        width: width,
        height: height,
        padding: padding,
        margin: margin,
        decoration: BoxDecoration(
          color: backgroundColor,
          border: Border.all(color: borderColor),
          borderRadius: borderRadius,
        ),
        constraints: BoxConstraints(
          minWidth: width ?? 80,
        ),
        child: TextButton(
          onPressed: enable ? onPressed : null,
          child: child ??
              Text(
                text,
                style: TextStyle(color: textColor, fontSize: fontSize),
              ),
          style: ButtonStyle(
            backgroundColor: MaterialStateProperty.all(backgroundColor),
            overlayColor: MaterialStateProperty.all(overlayColor),
            shape: MaterialStateProperty.all(RoundedRectangleBorder(borderRadius: borderRadius)),
            padding: MaterialStateProperty.all(EdgeInsets.zero),
            visualDensity: VisualDensity.compact,
            minimumSize: MaterialStateProperty.all(Size.zero),
          ),
        ),
      ),
      visible: visible,
    );
  }
}
