import 'package:eyflutter_core/eyflutter_core.dart';
import 'package:eyflutter_uikit/eyflutter_uikit.dart';
import 'package:eyflutter_uikit_example/primary_button.dart';
import 'package:flutter/material.dart';

class SingleTextEditDialog {
  factory SingleTextEditDialog() => _getInstance();

  static SingleTextEditDialog get instance => _getInstance();
  static SingleTextEditDialog? _instance;

  SingleTextEditDialog._internal();

  static SingleTextEditDialog _getInstance() {
    return _instance ??= SingleTextEditDialog._internal();
  }

  YYDialog? _editDialog;

  /// 显示编辑弹窗
  void show({
    required BuildContext context,
    required String title,
    required Function() complete,
    String? hintText,
  }) {
    var editModel = _SingleTextEditModel(title: title, hintText: hintText ?? "");
    _editDialog = Dialogs.instance.showDialog(context,
        gravity: Gravity.bottom,
        margin: EdgeInsets.zero,
        padding: EdgeInsets.zero,
        isKeyboardAvoiding: true,
        borderRadius: const BorderRadius.only(
          bottomLeft: Radius.zero,
          bottomRight: Radius.zero,
          topLeft: Radius.circular(16),
          topRight: Radius.circular(16),
        ),
        backgroundColor: const Color(0xffFCF7EB),
        contentView: _SingleTextEditWidget(
          editModel: editModel,
          closeCall: () {
            _editDialog?.dismiss();
            _instance = null;
          },
          complete: () {
            _editDialog?.dismiss();
            complete();
            _instance = null;
          },
        ));
  }
}

class _SingleTextEditModel {
  final String title;
  final String hintText;
  OnFormFieldController? controller;
  String editContentTag = "0474047a2d4cb0ce";

  _SingleTextEditModel({required this.title, required this.hintText});
}

class _SingleTextEditWidget extends StatefulWidget {
  final _SingleTextEditModel editModel;

  final Function closeCall;

  final Function complete;

  const _SingleTextEditWidget({Key? key, required this.editModel, required this.closeCall, required this.complete})
      : super(key: key);

  @override
  _SingleTextEditWidgetState createState() => _SingleTextEditWidgetState();
}

class _SingleTextEditWidgetState extends State<_SingleTextEditWidget> {
  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisSize: MainAxisSize.min,
      children: [
        SizedBox(
          width: double.infinity,
          height: 54,
          child: Stack(
            children: [
              buildTitle(),
              buildCancel(),
              buildComplete(),
            ],
          ),
        ),
        buildEditView(),
      ],
    );
    return AnimatedContainer(
      duration: const Duration(milliseconds: 200),
      curve: Curves.easeOutSine,
      transform: Matrix4.translationValues(0.0, MediaQuery.of(context).viewInsets.bottom * 1.0, 0.0),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          SizedBox(
            width: double.infinity,
            height: 54,
            child: Stack(
              children: [
                buildTitle(),
                buildCancel(),
                buildComplete(),
              ],
            ),
          ),
          buildEditView(),
        ],
      ),
    );
  }

  Widget buildComplete() {
    return Align(
      child: PrimaryButton(
        onPressed: () => widget.complete(),
        text: "完成",
        textColor: const Color(0xb33B372C),
        fontSize: 14,
        width: 42,
        height: 20,
        borderRadius: const BorderRadius.all(Radius.circular(6)),
        margin: const EdgeInsets.only(right: 13),
        borderColor: Colors.transparent,
        backgroundColor: Colors.transparent,
      ),
      alignment: Alignment.centerRight,
    );
  }

  Widget buildTitle() {
    return Center(
      child: Text(
        widget.editModel.title,
        style: const TextStyle(color: Color(0xe63B372C), fontSize: 16),
        textAlign: TextAlign.center,
      ),
    );
  }

  Widget buildCancel() {
    return Align(
      child: PrimaryButton(
        onPressed: () => widget.closeCall(),
        text: "取消",
        textColor: const Color(0xb33B372C),
        fontSize: 14,
        width: 42,
        height: 20,
        borderRadius: const BorderRadius.all(Radius.circular(6)),
        margin: const EdgeInsets.only(left: 13),
        borderColor: Colors.transparent,
        backgroundColor: Colors.transparent,
      ),
      alignment: Alignment.centerLeft,
    );
  }

  Widget buildEditView() {
    return TextFields(
        items: [
          TextFieldItem(
              tag: widget.editModel.editContentTag,
              hintText: widget.editModel.hintText,
              validator: (value) {
                if (value.isEmptyString) {
                  return widget.editModel.hintText;
                }
                return null;
              }),
        ],
        controllerCall: (controller) {
          widget.editModel.controller = controller;
        });
  }
}
